@@ -241,7 +241,11 @@ class CortxJupyter(ContentsManager):
 # The documentation suggests that leading slashes in the
 # path are not present, but they are, mostly
 def _key(context, path):
-    return context.prefix + path.lstrip('/')
+    print(path)
+    print(path.lstrip('/'))
+    # return context.prefix + path.lstrip('/')
+    return context.prefix + path
+
 
 
 def _path(context, key):
@@ -321,8 +325,7 @@ def _exists(context, path):
 @gen.coroutine
 def _get(context, path, content, type, format):
     type_to_get = type if type is not None else (yield _type_from_path(context, path))
-    format_to_get = format if format is not None else _format_from_type_and_path(
-        context, type_to_get, path)
+    format_to_get = format if format is not None else _format_from_type_and_path(context, type_to_get, path)
     return (yield GETTERS[(type_to_get, format_to_get)](context, path, content))
 
 
